package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@$!`0````````````,`*``!````'1@``#0```#4L0````0`!30`(``)
M`"@`'``;``$``'#0H```T*```-"@```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#<H```W*````4```````$`
M`0```'BM``!XK0$`>*T!`.0"``#\$@``!@```````0`"````A*T``(2M`0"$
MK0$`*`$``"@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D>*T`
M`'BM`0!XK0$`B`(``(@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50!B3GFQ.L-9F-PHV^_X;E1*85$LL1$```!1````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%$```!2````5@``
M`%L```!<````8P```&0```!E````9P```&@`````````:@```&L```!L````
M;@```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M```````````````````````@$P````````,`"P``````@*T!```````#`!0`
MS0(`````````````$@```'L#`````````````!(```!/`P`````````````B
M````E`,`````````````$0```#\$`````````````!(````1````````````
M```@````/@(`````````````$@```"$#`````````````!(```!L`P``````
M```````2````)0$`````````````$@```+(#`````````````!$```#(````
M```````````2````Z`(`````````````$@```)<!`````````````!(```#4
M`@`````````````2````F```````````````$@```"`!`````````````!(`
M``#O`@`````````````2````?@(`````````````$@```$T"````````````
M`!(```"/`@`````````````2````G`(`````````````$@```!4!````````
M`````!$```![`0`````````````2````]P``````````````$0```$D!````
M`````````!(````H`P`````````````2````&@,`````````````$0```#$#
M`````````````!(```#6```````````````2````Q0$`````````````$@``
M`#8"`````````````!(```"R`0`````````````2````"`,`````````````
M$@```!X"`````````````!(```"^`0`````````````2````@@,`````````
M````$@```%<!`````````````!(````M```````````````@````L0(`````
M````````$@```%\"`````````````!(```"_`@`````````````2````T`$`
M````````````$0```'@``````````````!(````^`P`````````````2````
MIP``````````````$@```"4"`````````````!(```!>`P`````````````2
M````LP``````````````$@```&P"`````````````!(```!P`0``````````
M```2````E@(`````````````$@```,8"`````````````!(````V`0``````
M```````2````:@``````````````$@```"H!`````````````!(```"G`0``
M```````````2````V@(`````````````$@````0!`````````````!(```"J
M`@`````````````2````=`,`````````````$@```+@"`````````````!(`
M``")`0`````````````2````AP``````````````$@```)4#````````````
M`"$````\```````````````@````10,`````````````$@```.@`````````
M`````!(```!G`0`````````````2````4```````````````(````)8#````
M`````````!$````0`P`````````````2````9`(`````````````$@```*0"
M`````````````!(````8`@`````````````2````_0(`````````````$@``
M`'4"`````````````!(````$`@`````````````2````]`,``'3``0``````
M$``8`$@$``!E7P``4````!(`#0`6!```%&`````````2``X`;00``*U4``#T
M!P``$@`-`(\#``!1%@``S`$``!(`#0`<!```24\```0````2``T`Y0,``%RP
M`0``````$``8`-L$``!-3P``M`$``!(`#0#5!```(!,````````2``L`"`4`
M`*%<``#$`@``$@`-`-D#``!<L`$``````!``&`!4!````5$``!8````2``T`
MAP0``!Q@```$````$0`/``<$``!TP`$``````!``&`#_`P``=,`!```````0
M`!@`TP0``"U.```X````$@`-`.@$``#54P``V````!(`#0#Z!```95,``&``
M```2``T`>@0```"P`0``````$``7`&$$```940``L````!(`#0#2`P``7+`!
M```````0`!<`O`0``%BP`0`$````$0`7``P$```18````@```!(`#0"L!```
MU5\``#P````2``T`@`0``!T8````````$@`-`'P$````L`$``````"``%P`M
M!```Q5,``!`````2``T`\P,``'3``0``````$``8`)8$``"Q3@``F````!(`
M#0#&!```R5$``)P!```2``T``&QI8G!E<FPN<V\N-2XR-`!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R
M0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A
M<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A
M9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L
M<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`
M<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N
M;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K
M`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M
M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V
M-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`
M<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V
M90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L
M9"UL:6YU>"UA<FUH9BYS;RXS`%]?<W1A8VM?8VAK7V=U87)D`&QI8F-R>7!T
M+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S7W-T87)T7U\`7U]B<W-?
M96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N
M=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A
M7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?
M7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET
M`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0``````````@`"``(`
M`@`"`````P`"``(``@`$`````@````(```````(``@`"``(``@``````````
M``(``@`"```````#`````@`#``(``@```````@`"``(```````(````#``(`
M```"`````@`"`````````````@````(``@`"```````"`````@`````````"
M``(``@`"``,``@`"``,``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`G@,``!`````@
M````%&EI#0``!``>!0````````$``0#T`0``$````"`````4:6D-```#`!X%
M`````````0`!`$,"```0`````````!1I:0T```(`'@4```````!XK0$`%P``
M`'RM`0`7````N*\!`!<```#<KP$`%P```.2O`0`7````[*\!`!<````$L`$`
M%P````RP`0`7````$+`!`!<````4L`$`%P```!BP`0`7````'+`!`!<````@
ML`$`%P```"BP`0`7````++`!`!<````TL`$`%P```#BP`0`7````/+`!`!<`
M``!`L`$`%P```$2P`0`7````3+`!`!<```!0L`$`%P```%BP`0`7````O*\!
M`!4%``#`KP$`%0@``,2O`0`5#0``R*\!`!40``#,KP$`%1D``-"O`0`5&P``
MU*\!`!4>``#8KP$`%2D``."O`0`5+0``Z*\!`!4X``#PKP$`%4(``/2O`0`5
M1```^*\!`!5(``#\KP$`%4D``+BN`0`6`P``O*X!`!8$``#`K@$`%@4``,2N
M`0`6!P``R*X!`!8)``#,K@$`%@H``-"N`0`6"P``U*X!`!8,``#8K@$`%@X`
M`-RN`0`6#P``X*X!`!81``#DK@$`%A(``.BN`0`6$P``[*X!`!84``#PK@$`
M%A4``/2N`0`6%@``^*X!`!87``#\K@$`%A@```"O`0`6&@``!*\!`!8<```(
MKP$`%AT```RO`0`6'P``$*\!`!8@```4KP$`%B$``!BO`0`6(@``'*\!`!8C
M```@KP$`%B0``"2O`0`6)0``**\!`!8F```LKP$`%B<``#"O`0`6*```-*\!
M`!8I```XKP$`%BH``#RO`0`6*P``0*\!`!8L``!$KP$`%BX``$BO`0`6+P``
M3*\!`!8P``!0KP$`%C$``%2O`0`6,@``6*\!`!8S``!<KP$`%C0``&"O`0`6
M-0``9*\!`!8V``!HKP$`%C<``&RO`0`6.0``<*\!`!8Z``!TKP$`%CL``'BO
M`0`6/```?*\!`!8]``"`KP$`%CX``(2O`0`6/P``B*\!`!9```",KP$`%D$`
M`)"O`0`610``E*\!`!9&``"8KP$`%D<``)RO`0`62@``H*\!`!9+``"DKP$`
M%DP``*BO`0`630``K*\!`!9.``"PKP$`%D\``+2O`0`64```"$`MZ4X!`.L(
M@+WH!.`MY03@G^4.X(_@"/"^Y7";`0``QH_B&<J,XG#[O.4`QH_B&<J,XFC[
MO.4`QH_B&<J,XF#[O.4`QH_B&<J,XEC[O.4`QH_B&<J,XE#[O.4`QH_B&<J,
MXDC[O.4`QH_B&<J,XD#[O.4`QH_B&<J,XCC[O.4`QH_B&<J,XC#[O.4`QH_B
M&<J,XBC[O.4`QH_B&<J,XB#[O.4`QH_B&<J,XAC[O.4`QH_B&<J,XA#[O.4`
MQH_B&<J,X@C[O.4`QH_B&<J,X@#[O.5X1\!&`,:/XAG*C.+T^KSE`,:/XAG*
MC.+L^KSE`,:/XAG*C.+D^KSE`,:/XAG*C.+<^KSE`,:/XAG*C.+4^KSE`,:/
MXAG*C.+,^KSE`,:/XAG*C.+$^KSE`,:/XAG*C.*\^KSE`,:/XAG*C.*T^KSE
M`,:/XAG*C.*L^KSE`,:/XAG*C.*D^KSE`,:/XAG*C.*<^KSE`,:/XAG*C.*4
M^KSE`,:/XAG*C.*,^KSE`,:/XAG*C.*$^KSE`,:/XAG*C.)\^KSE`,:/XAG*
MC.)T^KSE`,:/XAG*C.)L^KSE`,:/XAG*C.)D^KSE`,:/XAG*C.)<^KSE`,:/
MXAG*C.)4^KSE`,:/XAG*C.),^KSE`,:/XAG*C.)$^KSE`,:/XAG*C.(\^KSE
M`,:/XAG*C.(T^KSE`,:/XAG*C.(L^KSE>$?`1@#&C^(9RHSB(/J\Y7A'P$8`
MQH_B&<J,XA3ZO.4`QH_B&<J,X@SZO.4`QH_B&<J,X@3ZO.4`QH_B&<J,XOSY
MO.4`QH_B&<J,XO3YO.4`QH_B&<J,XNSYO.4`QH_B&<J,XN3YO.4`QH_B&<J,
MXMSYO.4`QH_B&<J,XM3YO.4`QH_B&<J,XLSYO.4`QH_B&<J,XL3YO.4`QH_B
M&<J,XKSYO.4`QH_B&<J,XK3YO.4`QH_B&<J,XJSYO.4`QH_B&<J,XJ3YO.4`
MQH_B&<J,XISYO.4`QH_B&<J,XI3YO.4`QH_B&<J,XHSYO.4`QH_B&<J,XH3Y
MO.4`QH_B&<J,XGSYO.4`QH_B&<J,XG3YO.4`QH_B&<J,XFSYO.4`````\+6)
ML%Y,7TM\1`60!)$%J`.2!*GF6`.J,V@'D__W/.]92EI+HEC@6!%&!/";_%A+
MXU@?>``O<=!62^58*&C_]]COD/@.-`)&*&A#\`(#@O@.-/_WSN\%FP4SL_&`
M3Y#X#B1"\`$"@/@.)'32F`#_]]CN24L$G4_P!`Y[1$=*2$DO:'I$'&AY1$9+
M>T1#^/3L0F`%FL%@`2I#^/`,!V#(ORL=A&#$OP7K@@4`\0P!!=U3^`1+G4)!
M^`1/^=$Z3P+Q@$$`)`,Q?T0`E$#X(4`#1E?XZ%P#,C5)*$9Y1/_W*.\$1F"S
M,DT&KWU$5?CH#/_W;NXP2#E&>$0#\$KY*+,N2WM$4_CH#/_W/.[_]P;O!YHS
M:"!&FD(NT0FP\+W_]W3N)DIZ1$+XZ`PXL__W).X92^58*&C_]USO@/A]=G[G
M5_CH#/_W+.\$1LSG5?CL#$"Q!/#@^]/G&DL:2.%8>$3_][KN&4@Y1GA$`_`2
M^47X[`P`*,30[.?_]Q#N`2#_]X#N4)@!`!@!```\`0``1`$``"0!```@`0``
MBID!`(9,``"&3```>JH!`#ZJ`0`W-P``'*H!`,I)```$J@$`XJD!`#0!``"0
M2@``]D@``$_P``M/\``.`KQJ1@2T`;3?^"2@"*.:1-_X(,!:^`S`3?@$S09+
M6O@#,`9(6O@``/_W*.[_]][N6)8!``P!```X`0``0`$``!0PG^44()_E`S"/
MX`(@D^<``%+C'O\O`0W__^HXE@$`+`$```=+"$A[1`A*>$0#,QL:>D0&*P/9
M!4O36`.Q&$=P1P"_S)<!`,B7`0`2E@$`%`$```A)"4AY1`E+>$0)&GM$B1`!
MZ]%Q21`#T`5*FU@#L1A'<$<`OYR7`0"8EP$`Y)4!`$P!```(M0I+"DI[1'I$
M&WAKN0E+TU@CL0A+>T08:/_W*.W_][W_!DL!(GM$&G`(O6:7`0"TE0$`$`$`
M`/Z6`0!&EP$`!T@(M7A$`F@&2WM$$KF]Z`A`N^<$2IM8`"OXT)A']N=,E`$`
M<I4!`$@!``#?^.0NW_CD/BWI\$]Z1*WU/WT`\3@%'*P`\7@.`)0`)AJ0TUC-
MZ0:)&Y,;:+V3:&@(-0.6$#0%E@,*`I,##@23W>D"(P$&W>D$B0`C`O1_0E7X
M"'Q(Z@((3^H`*DGJ`PEU14)&"O1_`$+J`0)$^`QL2T8_ND_P``%"Z@`"0^H!
M`T3X$'Q$Z0(CT=$-\6@.#?4:?'1&_ND"`=3I'&?4Z1(CU.D&17)`>T!B0&M`
M0D!+0)`8YD5/ZM)X2.I#"$_P``-`Z@@"SND@(^/1&I@`)0"9+T;0Z0`TT>D`
MB:-&`"0F1LWI!F=>1II&=0$&1M#I`@%%ZMIES>D(JP_VW%S<Z0"\*D;-Z1`!
M,$;6Z01G&^L("TSK"0S81LWI!&<&1M#I!@'A1M;I"&?=Z02\S>D*`5!&S>D4
M9T0!W>D*9R)#W>D418OJ!@N,Z@<,%.L(!%Y&W>D0JT7K"06@1F=&&.L""%1&
M!.H&!*E&748F1@7J!P7=Z0HT2?$`"2]&749S0*T'!Y5\0!Y&!YL8ZP8"548G
M1D/JF@,'DTGK!P-41J@(0.J+<)M&HP<`G`:3%T9/\``(3_``"<WI`GBF1I)&
MU.D"1=WI!B-+1MWI`HE/\``,S>D&10)#S>D,(T1&W>D$B>8.W>D"18CJ`@B)
MZ@,)#_;L0]/I`"-&ZD46W>D&1:0874$B1BM&W>D(103J"`0%Z@D%H$8"G*E&
M8`'=Z0I%,$.D&%U!S>D&1=WI!#3=Z09G@^H(`X3J"03=Z0B)]AAG0<WI!F='
M1KP(W>D&9T3JB70V&$!&3^J`<D?Q``<B0][I!$4*Z@(*S>D.9Q-&W>D.B<WI
M%D4`)2Q&"^H%"\WI$C1/\``)W>D6-$_J21?-Z0:K1^K89P_V1$O;Z0"K3^I(
M%D_JV6$`(!KK`PK=Z0PC2^L$"]WI!$44ZPH$1>L+!=WI`JLBZ@H*(^H+"U)&
M6T9'Z@8*0>H'"]WI!F?-Z1:KW>D"JQ9#I!E'Z@,'?4%11B9&C`@6F1;K`0K=
MZ0)G1?$`"\WI%JM/\``+S>D"JT3JAW2R!R)#W>D"1=[I!F<`(9-&S>D&`6L!
M!Y,/]K`ST^D`(^`.0.I%$)(9>T$61A]&W>D.(\WI#KP"Z@L"`^H,`Y)&!YJ;
M1D+JU&,'D]WI#"-D`0:4DAG=Z09%>T$61@1#'T;=Z1(C`"`BZ@@"(^H)`TKJ
M`@I+Z@,+%NL*!D_JB7-'ZPL'%NL$"T?Q``Q#ZI@#3^J(<EY&9T9/\``,V$8:
M0\WI&&=C1M[I"&=/\``)#_8</-SI`+Q/ZDD5S>D,(T7JV&4;ZP8+3^I(%$SK
M!PQ/ZMEA7D;=Z1:K"NH""@OJ`PO=Z1(CDAG=Z0)G0^L,`\WI!B/=Z0XC3_``
M#"+J!@8CZ@<'2NH&"DOJ!PO=Z09G%NL*!D7J!`I'ZPL'0>H%"\WI!JO=Z0*K
M44:,"`:9%NL!"D_P``%'\0`+W>D"9\WI%JM/\``+S>D"JT3JAW2R!R)#W>D"
M1<WI!@'>Z0IGDT9K`0>3#_9H(]/I`"/@#LWI$KQ`ZD40DAE[019&'T;=Z1@C
M`NH+`@/J#`.21@>:FT9"ZM1C!Y/=Z0XC9`$&E-Q&DAE[019&'T;=Z0PCW>D&
M12+J"`(CZ@D#2NH""TSJ`PP6ZPL&1.H`!$?K#`=/ZHES%NL$"T/JF`-'\0`,
M3^J(<LWI&+Q/\``,V$;>Z0QG&D-C1@_VW!S<Z0"\3_``"<WI#B-/ZDD5&^L&
M"T7JV&5,ZP<,3^I(%%Y&W>D6JT_JV6$`(`KJ`@H+Z@,+W>D,(Y(9W>D"9T/K
M#`/-Z08CW>D2(T_P``PBZ@8&(^H'!TKJ!@I+Z@<+W>D&9Q;K"@9%Z@0*1^L+
M!T'J!0O-Z0:KW>D"JU%&C`@&F1;K`0I/\``!1_$`"]WI`F?-Z1:K3_``"\WI
M`JM$ZH=TL@<B0]WI`D7-Z08!WND.9Y-&:P$'DP_V(!/3Z0`CX`[-Z0R\0.I%
M$)(9>T$61A]&W>D8(P+J"P(#Z@P#DD8'FIM&0NK48P>3W>D2(V0!!I3<1I(9
MW>D&17M!%D8$0Q]&W>D.(P`@(NH(`B/J"0-*Z@(+3.H##!;K"P9/ZHES1^L,
M!Q;K!`M'\0`,0^J8`T_JB')>1F=&3_``#-A&&D/-Z1AG8T;>Z1!G3_``"0_V
MC`S<Z0"\3^I)%<WI$B-%ZMAE&^L&"T_J2!1,ZP<,3^K985Y&W>D6JPKJ`@H+
MZ@,+W>D.(Y(9W>D"9T/K#`/-Z08CW>D,(T_P``PBZ@8&(^H'!TKJ!@I+Z@<+
MW>D&9Q;K"@9%Z@0*1^L+!T'J!0O-Z0:KW>D"JU%&C`@&F1;K`0I/\``!1_$`
M"]WI`F?-Z1:K3_``"\WI`JM$ZH=TL@<B0]WI`D7-Z08!WND29Y-&:P$'DP_R
MV'/3Z0`CX`[-Z0Z\0.I%$)(9>T$61A]&W>D8(P+J"P(#Z@P#DD8'FIM&0NK4
M8P>3W>D,(V0!!I3<1I(9W>D&17M!%D8$0Q]&W>D2(P`@(NH(`B/J"0-*Z@(+
M3.H##!;K"P9/ZHES1^L,!Q;K!`M'\0`,0^J8`\WI&+Q/ZHAR3_``#-A&WND4
M9QI#8T8/\DA\W.D`O,WI#"-/\``)&^L&"T_J215,ZP<,1>K895Y&W>D6JT_J
M2!1/ZMEA"NH""@OJ`PO=Z1(CDAG=Z0)G0^L,`\WI!B/=Z0XC3_``#"+J!@8C
MZ@<'2NH&"DOJ!PO=Z09G%NL*!D7J!`I'ZPL'0>H%"\WI!JO=Z0*K44:,"`:9
M%NL!"D_P``%'\0`+W>D"9\WI%JM/\``+S>D"JT3JAW2R!R)#W>D"1<WI!@'>
MZ19GDT9K`0>3#_*08]/I`"/@#LWI$KQ`ZD40DAE[019&'T;=Z1@C`NH+`@/J
M#`.21@>:FT9"ZM1C!Y/=Z0XC9`$&E-Q&DAG=Z09%>T$61@1#'T;=Z0PC`"`B
MZ@@"(^H)`TKJ`@M,Z@,,%NL+!D_JB7-'ZPP'%NL$"T?Q``Q#ZI@#S>D8O$_J
MB')/\``,V$;>Z1AG&D-C1@_R!&S<Z0"\S>D.(T_P``D;ZP8+3^I)%4SK!PQ%
MZMAE7D;=Z1:K3^I(%$_JV6$*Z@(*"^H#"]WI#".2&=WI`F=#ZPP#S>D&(]WI
M$B-/\``,(NH&!B/J!P=*Z@8*2^H'"]WI!F<6ZPH&1>H$"D?K"P=!Z@4+S>D&
MJ]WI`JM11HP(!ID6ZP$*3_```4?Q``O=Z0)GS>D,JT_P``O-Z0*K1.J'=+('
M(D/>Z1IGW>D"1<WI!@&31LWI%KQK`0>3#_)(4]/I`"/@#D#J11"2&7M!%D8?
M1MWI&","Z@L"`^H,`Y)&!YJ;1D+JU&,'D]WI$B-D`0:4W$:2&=WI!D5[019&
M!$,?1MWI#B,BZ@@"(^H)`TKJ`@M,Z@,,%NL+!D_JB7-'ZPP'%NL$"T?Q``Q#
MZI@#3^J(<EY&9T9/\``,V$8:0\WI!F=C1M[I'&=/\``)#_*X3-SI`+Q/ZDD5
MS>D2(T7JV&4;ZP8+3^I(%$SK!PQ/ZMEA7D;=Z0RK"NH""@OJ`PO=Z0XCDAG=
MZ0)G0^L,`\WI#"/=Z18C(NH&!B/J!P=*Z@8*2^H'"]WI#&<`(Q;K"@9%Z@0*
M1^L+!T'J!0O-Z0RKW>D"JU%&C`@,F1;K`0I/\``!1_$`"]WI`F?-Z0ZK3_``
M"T_J2Q5$ZH=TL@<B0][I'F=%ZMIE3^I*%!!&`"+-Z0(C3^K:8P*3_Z/3Z0`C
MS>D,`9(9>T'=Z0QG$$891MWI!B,"E3)`.T`61A]&W>D6(X`864'=Z1(C(NH(
M`B/J"0,60Q]#,D9/ZMMF`Y:&&#M&0>L#!]WI`@$`(QU&`"(@0T_JB7,41D/J
MF`/-Z0)%3^J(<D_JF`1/ZID!`I1/\``(-!A/\``)`I-'\0`%2T;>Z2!GS>D6
M145&#_)L.=GI`(D#D=WI`@$8ZP8(2>L'"<WI`D400T9&3T;=Z0Z)`D8`(0`@
MS>D&`6D!X`X'D0CJ`@C=Z0)%">H#"<WI#B,'FD#J11!"ZM1C!Y/=Z1(C9`$&
ME)(9W>D&17M!%D8$0Q]&W>D,(P`@(NH*`B/J"P-(Z@((2>H#"1;K"`9/ZHMS
M1^L)!Q;K!`A'\0`)0^J:`\WI&(E/ZHIR3_``"<)&WNDB9QI#2T8/\L0IV>D`
MB<WI$B-/\``+&.L&"$_J2Q5)ZP<)1>K:949&3^I*%$]&W>D6B4_JVV$(Z@((
M">H#"=WI#".2&7M!W>D"9\WI!B/=Z0XC(NH&!B/J!P=(Z@8(2>H'"=WI!F<6
MZP@&1>H$"$?K"0=!Z@4)S>D&B=WI`HE!1HP(!ID6ZP$(3_```4?Q``G=Z0)G
MS>D6B<WI`@$`(43JAW2R!T=&3_``",WI!G@B0]WI!D6)1M[I)&>01LWI#(D-
M];A^:P$#DX"CT^D`(^`.J49`ZD40DAE[019&'T;=Z1@C`NH(`@M`S>D&(Z!&
M`YI/ZIL!0NK48P.3W>D.(V0!`I22&=WI!D5[0<WI!HD61MWI`HD?1MWI$B-(
MZ@`((NH*`B/J"P,40QU#-AE/ZHIT;T$6ZP@"1_$``T_JBW5%ZIH%%T:81@";
M1.H%"T7J`0S-Z0YX`"201@`E($8I1LWI`@%/ZMAA`I%>1MWI%@%G1M/I)B-/
M\``*#_)0'-SI`+PP0,WI&&<`)SE`S>D69]WI$F<;ZP(+3.L##-WI!B,6ZPL&
M3^I*%4?K#`?=Z0R\T49%ZMAE+.H#`P*5"T,KZ@("3^K:80.1W>D"JT_J2!0"
M0P`@MAA*Z@0*7T$6ZPH"W>D&JT?Q``,61A]&`"-:1LWI$F>5!U)&E`=:1D7J
MF@61"`":1>H!"T3J!0K=Z1A%'T;-Z0:KTNDH(X7J"P4/\K0,W.D`O(3J"@0`
M(<WI`@$;ZP(+($9,ZP,,>0%<1MWI#JL#D2E&BNH`"F5&B^H!"\WI#JO=Z0R\
M<0$#F_(.`I$;ZP0+#IE,ZP4,0^K68T_JB74#DQOK`0I%ZI@%W>D"`4_JB'1/
MZID!1.H%"$+J1Q)%Z@$)0.H"`$SQ``L:ZP`*249`1MWI!HE+\0`+`)L`)(CJ
M``C-Z1BK3_``"P`ET^DJ(\WI`D4.X`"_K_,`@)EY@EH`````H>O9;@````!$
ME0$`&`$``$_J2Q0#E$1&#_:4:=GI`(F]!\WI#`%%ZI8%&.L""$_JVF))ZP,)
M`YM`1D+J2Q))1MWI$HE#ZMIC`Y.(Z@0(1$;=Z1:)&.L`"$GK`0D8ZP0`3^I*
M$0*12?$``8!&M`<`GHE&W>D"`;D($$-%Z@$'&.L`"$GQ``G-Z1*)UNDL(T3J
M!08Y1MWI#$4P1LWI#@$/]A!AT>D``71`3_``"4_J2!:`&$_J21=90=WI&"/-
MZ18!1^K89P:98D`"ET_JV6,41@.3"D;=Z18!3^J+=8`81>J:!4'Q``$"&4'Q
M``/-Z08CW>D"(T_JBG1/ZIL!1.H%"C)#W>D&9T7J`0M41K881_$`!UU&,D;=
MZ0ZK.T;-Z18C`)H`(Q]&#_:(7-SI`+QY`8KJ!`K2Z2XCS>D&151&&^L""T_J
MB75,ZP,,0>K68]WI$A)%ZI@%`Y/R#F%`0NI'$@";#$8,F1OK`0!,\0`!`!E/
MZHATBT9/ZD81`I%+\0`!@D9$Z@4(BT;=Z0(!3^J9`0`D1>H!"1!#&NL`"D!&
M24;=Z0:)2_$`"\WI$JN(Z@`(3_``"]/I,",`)<WI`D5/ZDL4`Y1$1@_VZ$G9
MZ0")O0?-Z0P!1>J6!1CK`@C=Z1822>L#"0.;84!/ZMIB0^K:8P.3#$8.F4+J
M2Q(8ZP$`2?$``0`93^J&=`">B49/ZDH1`I%)\0`!@$:)1MWI`@&Y"!!#1>H!
M!];I,B-$Z@4&&.L`"#E&,$;-Z0X!#_9T0='I``%)\0`)W>D,14_JBW6`&,WI
M%HE90=WI$B-T0,WI&`$&F6)`3_``"4_J2!841D_J21<*1MWI&`%'ZMAG3^K9
M8X`8`Y,"ET'Q``$"&47JF@5!\0`#S>D&(]WI`B-/ZHIT3^J;`43J!0HR0]WI
M!F=%Z@$+5$:V&$?Q``==1C)&W>D.JSM&S>D2(P":`",?1@_VX#S<Z0"\>0&*
MZ@0*TNDT(\WI!D541AOK`@M/ZHEU3.L##$'JUF/=Z182\@X#DT+J1Q)A0$7J
MF`4`FPQ&#)D;ZP$`3/$``0`93^J(=(M&3^I&$0*12_$``8)&1.H%"(M&W>D"
M`4_JF0$`)!!#1>H!"1KK``K3Z38C2_$`"\WI%JM/\``+0$9)1@`ES>D"14_J
M2Q0#E+T'W>D&B47JE@7-Z0P!B.H`"$1&#_8T.=GI`(D8ZP((W>D2$DGK`PD#
MFV%`3^K:8D/JVF,#DPQ&#IE"ZDL2&.L!`$GQ``$`&4_JAG0`GHE&3^I*$0*1
M2?$``8!&B4;=Z0(!N0@00T7J`0?6Z3@C1.H%!ACK``@Y1C!&S>D.`0_VS"'1
MZ0`!2?$`"=WI#$5/ZHMU@!C-Z1*)64'=Z18C=$#-Z1@!!IEB0$_P``E/ZD@6
M%$9/ZDD7"D;=Z1@!1^K89T_JV6.`&`*7`Y-!\0`!`AE%ZIH%0?$``\WI!B/=
MZ0(C3^J*=$_JFP%$Z@4*,D/=Z09G1>H!"U1&MAA'\0`'748R1MWI#JL[1LWI
M%B,`F@`C'T8/]C@LW.D`O'D!BNH$"M+I.B/-Z09%5$8;ZP(+3^J)=4SK`PQ!
MZM9CW>D2$O(.`Y-"ZD<284!%ZI@%#$8,F1OK`0!,\0`!`!E/ZHAT3_``#(M&
M3^I&$0*12_$``8)&1.H%"(M&W>D"`4_JF0$00T7J`0D:ZP`*0$9+\0`+S>D2
MJP";24;=Z09%3_``"\WI#`%/ZDL9T^D\(T1`#_:<$='I``%)ZMIIS?@(D$_J
M2AB`&$_JAW590=WI%B/-Z1@!3^K;8PZ98D`#DT7JE@441@I&W>D8`8`80?$`
M`0(90?$``\WI#B/=Z0(CM`>Y"``C0NH(`MWI#HD`GACK`@A)\0`)S>D6B4)&
MS>D"(T3J!0)%Z@$#UND^9T_JFP4<1A-&`YK-Z0XT3^I"&=WI#!)90`_V"!/3
MZ0`CDAE[01]&`IM)ZM-IW>D2-$M`&$8&F]88`IM'\0`',AA/ZHIV3^I#&$?Q
M``-(Z@D`3^J+=Q(81^J:!T/Q``/>Z0")$48-]1Y^&D9'Z@4#S>D2$@`B"$81
M1D;J!P(?1MWI#C1/ZD$;%D;-Z09G4T!+ZM!K3^I`&AQ&#_:(`]/I`",2ZP@"
M0^L)`]WI%HD?1@R;B.H$"$OJ"@36&-WI`JM'\0`'%NL(`D?Q``,2&4/Q``-/
MZHMYS>D6(P`D$T;-Z0`T6T9)ZIH)3^J*>)\(2.H)!$GJ!P5>J]WI!G@N1B5&
M`9QO0-/I`",/]AP)V>D`B4_J1!L`G!CK`@C-Z0)62>L#"4OJU&L.G$)&2T82
M&=WI$HD`G$/Q``.(Z@<(3^J!>4GJD`F/"$_J1!I&1I092NH+`D/Q``5/ZH!X
M%.L""DCJ"01%\0`+2>H'!=WI`HDF1B]&8*F(Z@0(W>D61='I``$`(X3J"`3-
MZ0QG#_*8=]?I`&=21J!&!IS-Z0ZK-AA/ZD,;3T%+ZMIK-AE/ZDH:1_$`!TOJ
M"@`6ZP@$1_$`!13K``I%\0`+W>D`15!&S>D2JT_P``I/\``+3^J%>4_JA'A)
MZI0)KPC-Z0"K8JQ(Z@D*2>H'"]WI#'AA1M3I`$5.`<WI!JN'Z@H'#_(<>MKI
M`)H!EAGK!`D!G$KK!0K+1D3JT&3=Z0Z)3^J#>0&42>J2"0*<B.H'")\(9*L;
MZP0$1D9*\0`%3^K0:*)&1`$`E!KK!@1%\0`%2.I!&*)&JT;=Z0!%2>H'!43J
M"`1/ZH)X&NL$"DCJ"03=Z0:)2_$`"\WI%JM/\``+S>D`JR9&T^D`(R]&`9R(
MZ@8(S>D"9T_J@7D/\H1FUND`5DGJD`E/ZD0;K1A>00";-T9+ZM-KW>D2-`R<
M@^H(`T_J@'@N&0"<1_$`!T_J1!KT&$KJ"P9'\0`%BP@4ZP8+1?$`#$CJ"01)
MZ@,%9JF@1MWI`B/1Z0`!J4;-Z0Z)`"</\AQIV>D`B6)`!IQ>1ACK``C-Z0R\
M2>L!"4_J1QM`1DOJUFM)1MWI%HD`&4_J1AJ(Z@((0?$``4_P``Q"1H082NH+
M`$'Q``44ZP`*849%\0`+W>D`15!&S>D2JT_JA7E/ZH1X2>J4"6BLJPA(Z@D*
MU.D`14GJ`PM21MWI#II;1@_RG%O;Z0"KS>D610`DS>D&(P`ES>D`14P!`92)
MZ@()W>D6-,(.0NI,$D_JAG@3ZPH#1.L+!)I&`9NC1D/JT&,!D]WI##0"G(/J
M"0-/ZH=Y&NL$!$GJE@E+\0`%:JZB1D0!`)0:ZP,$1?$`!0`CHD:K1MWI`$6]
M"!1#&NL$"DOQ``O-Z1:K4D;-Z0`C2>H%`TCJ"0+=Z0:)UND`JXCJ`@B)Z@,)
MS>D,(P`B1$9-1@_R\$G9Z0")`"/-Z0(C&.L*"$GK"PG"1LM&W>D`B4-&VPX"
MDP*;0^I)$]WI$HD"DXCJ!`@.G(GJ!0G-Z1*)&NL$`T_JD05+\0`$W>D`JYA&
M;*E31D_J@'I>`5M&VPX#DQ*;3^J,>TOJD`L8ZP,(1/$`"4)&2T;=Z0*)2.H&
M"!+K"`9*Z@L"0_$`!TOJ!0.P1M'I`$6Y1MWI#&?-Z0XC3^I(&A9#S>D2B4_P
M``DP1MWI%F=/ZDD;!D!+ZMAK,$;=Z0QG%D`/\C1#T^D`(S!#2^H*!A(9W>D`
MJVM!'48&F](81?$``Q(80_$``\WI`B-;1IT'4T;=Z0*KF`ANJQKK!@K=Z0!G
M2_$`"\WI%JM/\``+S>D`JT7JE@5`ZH=PM`>Y"$3J``I%Z@$+W>D.1<WI!JO=
MZ1*\1.H*`M/I``$+Z@(+#)L!GEI&W>D&JP_RK#S<Z0"\`)\$Z@H$&^L`"T_J
M1A9,ZP$,&^L#"P";1NK79@.60NH$!DSQ``P;ZP8+3^K39$_J0Q,"DTSQ``P!
MFT_JB7'=Z0)G0>J8`4_JB'!$ZD,43^J9`R9#W>D&11OK!@M/\``)3/$`#,WI
M$KS81D#J`0M!Z@,,1.H+`LWI#+QPJ]WI%JM/ZDD6W>D,O$;JV&8*Z@(*T^D`
M`03J"P0.FU)&#_((.]OI`*L#ED+J!`8:ZP`*3^K89$OK`0L:ZP,*3^I($P*3
M2_$`"QKK!@K=Z0)G1.I)%$OQ``L`)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`
MGJ,(W>D,14'JE@&P!T'J`PM61D#J`0K-Z0ZKW>D2O$3J"@)RJ\WI`&<+Z@(+
M`9[3Z0`!6D;=Z0ZK#_*`+-SI`+QV`0:;!.H*!!OK``L`GTSK`0P;ZP,+`)M,
M\0`,1NK79@.60NH$!D_JB7'<#EL!`I,;ZP8+`9M!ZI@!W>D"9TSQ``Q/ZHAP
M1.I#%$_JF0,F0T_P``D;ZP8+3^I)%DSQ``S-Z1*\0>H##'2KV$9`Z@$+T^D`
M`4;JV&;=Z0Y%S>D&O$3J"P+=Z1:KW>D&O`KJ`@H,FP3J"P0#EE)&#_+<&]OI
M`*M"Z@0&3^K89!KK``I$ZDD42^L!"QKK`PI/ZD@3`I-+\0`+&NL&"MWI`F=+
M\0`+`"<F0S1&`9X:ZP0*`9Q+\0`+S>D6J[$'`)ZC"-WI!D5!ZI8!L`=!Z@,+
M5D9`Z@$*S>D,J]WI$KQ$Z@H"=JO-Z0!G"^H""P&>T^D``5I&W>D,JP_R5!S<
MZ0"\=@$.FP3J"@0;ZP`+`)],ZP$,&^L#"P";3/$`#$;JUV8#ED+J!`9/ZHEQ
MW`Y;`0*3&^L&"P&;3/$`#-WI`F=!ZI@!3^J(<$3J0Q1/ZID#)D/=Z0Q%&^L&
M"T_P``E,\0`,S>D2O-A&0.H!"T'J`PQ$Z@L"S>D.O'BKW>D6JT_J21;=Z0Z\
M1NK89@KJ`@K3Z0`!!.H+!`.64D8/\K0+V^D`JP:;0NH$!AKK``I/ZMAD2^L!
M"QKK`PI/ZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<
M2_$`"\WI%JNQ!P">HPC=Z0Y%0>J6`;`'0>H#"U9&0.H!"LWI!JO=Z1*\1.H*
M`GJKS>D`9POJ`@L!GM/I``%:1MWI!JL/\BP,W.D`O'8!#)L$Z@H$&^L`"P"?
M3.L!#!OK`PL`FPG@K_,`@*'KV6X`````W+P;CP````!,\0`,1NK79@.60NH$
M!D_JB7'<#EL!`I,;ZP8+`9M,\0`,W>D"9T'JF`%/ZHAP1.I#%$_JF0,F0]WI
M!D4;ZP8+3_``"4SQ``S-Z1*\V$9`Z@$+0>H##$3J"P+-Z0R\?*O=Z1:K3^I)
M%MWI#+Q&ZMAF"NH""M/I``$$Z@L$#IM21@_VE&O;Z0"K`Y9"Z@0&&NL`"D_J
MV&1+ZP$+&NL#"D_J2!,"DTOQ``L:ZP8*W>D"9T3J211+\0`+`"<F0S1&`9X:
MZP0*2_$`"[$'`)X!G,WI%JM!ZI8!L`>C"-WI#$5!Z@,+5D9`Z@$*S>D.J]WI
M$KQ$Z@H"?JO-Z0!G"^H""P&>T^D``5I&W>D.JP_V#&S<Z0"\=@$&FP3J"@0;
MZP`+`)],ZP$,&^L#"P";3/$`#$;JUV8#ED+J!`9/ZHEQW`Y;`0*3&^L&"P&;
M3/$`#-WI`F=!ZI@!3^J(<$3J0Q1/ZID#)D/=Z0Y%&^L&"T_P``E,\0`,S>D2
MO-A&0.H!"T'J`PQ$Z@L"S>D&O("KW>D6JT_J21;=Z0:\1NK89@KJ`@K3Z0`!
M!.H+!`R;4D8/]FQ;V^D`JP.60NH$!AKK``I/ZMAD2^L!"QKK`PI/ZD@3`I-+
M\0`+&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<2_$`"\WI%JNQ!P">
MHPA!ZI8!L`=!Z@,+@JM61D#J`0K-Z0!GT^D``=WI!D7-Z0RKW>D2O$3J"@(.
MFPOJ`@L!G@"?6D;=Z0RK#_;<3-SI`+QV`03J"@1&ZM=F&^L`"P.63.L!#!OK
M`PL`FT+J!`9,\0`,&^L&"TSQ``Q/ZHEQW`Y;`0*30>J8`0&;3^J(<-WI`F=$
MZD,43^J9`R9#W>D,11OK!@M/\``)3/$`#,WI$KS81D#J`0M!Z@,,1.H+`LWI
M#KR$J]WI%JM/ZDD6W>D.O$;JV&8*Z@(*T^D``03J"P0&FU)&#_9`2]OI`*L#
MED+J!`8:ZP`*3^K89$OK`0L:ZP,*3^I($P*32_$`"QKK!@K=Z0)G1.I)%$OQ
M``L`)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`GJ,(W>D.14'JE@&P!T'J`PN&
MJU9&S>D`9T#J`0H!GM/I``%$Z@H"S>D&J]WI$KQV`0R;"^H""P"?6D;=Z0:K
M#_:P/-SI`+Q&ZM=F!.H*!`.6&^L`"T+J!`9,ZP$,&^L#"P";3/$`#!OK!@M/
MZHEQ3/$`#$'JF`'<#EL!`I-/ZHAP`9O=Z0)G1.I#%$_JF0,F0]WI!D4;ZP8+
M3_``"4SQ``S-Z1*\V$9`Z@$+0>H##$3J"P+-Z0R\B*O=Z1:K3^I)%MWI#+Q&
MZMAF"NH""M/I``$$Z@L$#IM21@_V&#O;Z0"K`Y9"Z@0&&NL`"D_JV&1+ZP$+
M&NL#"D_J2!,"DTOQ``L:ZP8*W>D"9T3J211+\0`+`"<F0S1&`9X:ZP0*`9Q+
M\0`+S>D6J[$'`)ZC"-WI#$5!ZI8!L`=!Z@,+5D9`Z@$*S>D`9\WI#JM$Z@H"
MW>D2O(JK`9X`GPOJ`@O3Z0`!6D9V`=WI#JM&ZM=F#_:$+-SI`+P#E@3J"@0&
MFQOK``M,ZP$,0NH$!AOK`PL`FTSQ``P;ZP8+3/$`#$_JB7'<#EL!`I-!ZI@!
M`9M/ZHAPW>D"9T3J0Q1/ZID#)D/=Z0Y%&^L&"T_P``E,\0`,S>D2O-A&0.H!
M"T'J`PQ$Z@L"S>D&O(RKW>D6JT_J21;=Z0:\1NK89@KJ`@K3Z0`!!.H+!`R;
M4D8/]NP;V^D`JP.60NH$!AKK``I/ZMAD2^L!"QKK`PI/ZD@3`I-+\0`+&NL&
M"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<2_$`"\WI%JNQ!P">HPC=Z09%
M0>J6`;`'0>H#"U9&0.H!"LWI#*O=Z1*\1.H*`HZKS>D`9POJ`@L!GM/I``%:
M1MWI#*L/]F0<W.D`O'8!#IL$Z@H$&^L`"P"?3.L!#!OK`PL`FTSQ``Q&ZM=F
M`Y9"Z@0&3^J)<=P.6P$"DQOK!@L!FTSQ``S=Z0)G0>J8`4_JB'!/\``*1.I#
M%$_JF0,F0U=&&^L&"T#J`0I,\0`,S>D8O%Y&0>H#"U-&3_``"%Q&W>D,JT_P
M``G-Z0*)2NH#",WI#C1\`0.40D;=Z0Y%W>D6B9"I"NH$"<WI$F<(Z@((T>D`
M`4Q&#_:P#-SI`+Q"1MWI$HD#GAOK``M,ZP$,!IM!1D;JV&9'1@.620$!G@*1
M6$9"Z@0+_`[=Z0)XPAA$ZDD43/$``R=#$NL+`@&<3^J&<0">0_$``Q+K!PM/
M\``'0_$`#*,(0>J6`;`'7D;-Z0!GS>D6O``D0>H##``CS>D"-)*J`9M`Z@$+
MW>D.9]WI&(GA1M+I``%;`4;J"P(#DPCJ`@@&Z@L"`YY$1MA&#_8(#-SI`+PB
M0S=&`)X;ZP`+#)M,ZP$,1^K69P">6$;`&$SQ``&"&$_J1A,#EP*30?$``[M&
M%D8?1MWI`B-/\``,0NH+`A;K`@I'\0`+W>D29\WI&*O31LWI`KR]![0'1>J6
M!;D(1.H%"D7J`0L#FY2IW>D61<WI$HF(Z@H(`IJ$Z@@$S>D&JUL!T>D`O*!&
M#_*`<='I``%#ZM)C#IP;ZP`+'T9,ZP$,4P$;ZP0$`)Y,\0`%%.L("D/J!P@!
MFT7Q``NT!P&>&NL("D_J@W4`F]%&2_$`"[$(S>D6JT7JDP5*1D7J`0A$Z@4'
MEJE/\``*/49&1MWI!GA31LWI#%9O0-WI&$71Z0")?$`/\@AQT>D``<WI`",`
M)R9&$IP8ZP`(`)M)ZP$)&.L$!$GQ``7=Z0")V`X#FT_J1QM/ZD@:%.L&"$#J
M21!%\0`)G0<"FTKJ``88ZP8(1>J3!0*;1D9)\0`)S>D2B4OJUFN<!P.;1.H%
M"$_J1AJ9"$!&1>H!"9BK24;=Z0R)T^D`(XCJ``C-Z0X!1$8/\GQIV>D`B1CK
M`@A)ZP,)W>D6(P:9`"-B0!CK`0`41DGQ``$0ZP0(2NH+!-WI`+Q!\0`)`"+-
MZ0(C3_``"ACK!`AA1E5&3^J!<0.1`YA91D_JD0)$1D#JFP$#D5E&3_```$_J
M@7$"D6%&0NJ,<D_JD0-/\``!S>D``4GQ``G=Z0(!S>D6B<%&&4,00VL!`9.+
M1MWI#A*:JX)&04#-Z0*KT^D`O(A&#_+84M+I`!(!FQOK`0L,F4SK`@Q#ZMEC
M&^L!``&3W>D2(TSQ``&["(+J"`*+1F$!`)&01N(.$.L(`-WI`(E"ZD422_$`
M`4CJ`@A/\``)$.L("D_JAG!!\0`+N0=!ZI8!S>D2JT'J`PQ`Z@$+3^I)$P`F
M649B1MWI`KP`)\WI`&?01@&3B^H!"YRKS>D&$EY&#IG3Z0"K#_)`4]/I`",:
MZP(*2^L#"P&;&NL!`$/JV&,!D]WI%B-+\0`!JPAR0(M&3^I($0"1%D9/ZMAB
M@!G=Z0!G0NI)$DOQ``$60P`G$.L&"D_JA'!!\0`+J0=!ZI0!5D;-Z0ZK`"1`
MZ@$*0>H#"P`E>P'-Z0!%448!D]WI!C3-Z0RK2T#>Z0"\#_*\0M+I`!(-]2!^
M'$8!FQOK`0L"F4SK`@Q#ZM9C&^L!``&3W>D2(TSQ``%/ZID#3_``#&)`BT9Q
M`0"1%$;R#@`9W>D`14+J1Q)+\0`!%$-E1A#K!`I/ZHAP0?$`"T_JB7%!ZI@!
M5$9`Z@$(0>H#"<WI$JMK`<)&#_)$0M+I`!++1LWI`JO>Z0"\0^K48]WI#(D-
M]21^&^L!"P:9`9-,ZP(,W>D.(QOK`0!,\0`!B.H*"(+J"`*["(M&80$`D9!&
MX@X0ZP@`W>D`B4+J11)+\0`!3_``"4CJ`@@0ZP@*3^J&<$'Q``NY!T'JE@'-
MZ0ZK0>H##$#J`0M/ZDD3`"8`)\WI`&<!DZ*KT$991F)&W>D"J\WI!A+3Z0"\
MBNH!"NBCT^D`(PR95D8;ZP(+3.L##`&;&^L!`$/JV&,!D]WI$B-,\0`!JPAR
M0(M&3^I($0"1%D9/ZMAB@!G=Z0!G0NI)$DOQ``$60P`G$.L&"D_JA'!!\0`+
MJ0=!ZI0!`"5!Z@,,`"1[`<WI`$4!DU9&W>D&-,WI$JM`Z@$+@^H+`\WI#+S>
MZ0`2#?4F?@_R%#O;Z0"K'$8!FT_P``P1ZPH!0NL+`D/JUF.*1@*9`9.31AKK
M`0#=Z0XC2_$``4_JF0-B0(M&<0$`D11&\@X`&=WI`$5"ZD<22_$``65&%$,0
MZP0*3^J(<$'Q``M/ZHEQ0>J8`51&S>D.JT#J`0E!Z@,*WND`$FL!#?4J?M-&
MRD;=Z0R)0^K48\WI`JN(Z@H(#_*$*]OI`*L!DQ'K"@%"ZPL"BD8&F9-&W>D2
M(QKK`0!/ZI<#2_$``8+J"`*+1F$!`)&01N(.$.L(`-WI`(E"ZDP22_$``4_P
M``E(Z@(($.L("D_JAG!!\0`+N0=!ZI8!`"<`)LWI`&=`Z@$&0>H#!]WI`A)/
MZDD3`9.HJW%`T$;-Z09GS>D2JPY&#_+X&]OI`*O3Z0`2`9L1ZPH!0NL+`D/J
MV&.*1@R9DT8!D]WI#B,:ZP$`2_$``:L(<D"+1D_J2!$61@"1@!E/ZMABW>D`
M9T+J21)+\0`!`"<60Q#K!@I/ZH1P0?$`"ZD'0>J4`0`E0>H##``D>P'-Z0!%
M`9-61MWI!C3-Z0ZK0.H!"X/J"P/-Z0R\WND`$D_P``P/\F@;V^D`JQQ&`9L-
M]2Q^$>L*`4+K"P)#ZM9CBD8"F0&3DT8:ZP$`W>D2(TOQ``%/ZID#8D"+1G$!
M`)$41O(.`!G=Z0!%0NI'$DOQ``%E1A1#$.L$"D_JB'!!\0`+3^J)<4'JF`%4
M1LWI$JM/\``(0>H#"D_P``G-Z0")0.H!"5)&:P%)1@&3S>D"$M[I`*L-]3!^
M-:/3Z0`CW>D,B1KK`@I+ZP,+B.H!"`&;!IE#ZM1C`9,:ZP$`W>D.(TOQ``&[
M"(+J"`*+1F$!`)&01N(.$.L(`-WI`(E"ZDP22_$``4_P``E(Z@(($.L("D_J
MAG!!\0`+N0=!ZI8!T$;-Z0ZK0.H!"D'J`PL`)@`GS>D`9U9&7T;=Z0*K3^I)
M$P&3KJN*Z@8*$:+2Z0`2S>D&9U9&T^D`JP&;&NL!"D/JV&,!DPR92^L""]WI
M$B.K"!KK`0!+\0`!<D"+1D_J2!$)X*_S`(#<O!N/`````-;!8LH``````)$6
M1D_JV&*`&=WI`&="ZDD22_$``0`G%D,0ZP8*3^J$<$'Q``NI!T'JE`$`)4'J
M`PP`)'L!S>D`10&35D;=Z08TS>D2JT#J`0N#Z@L#S>D,O-FBTND`$D_P``S>
MZ0"K'$8!FPWU,GX:ZP$*`IE+ZP(+0^K68QKK`0`!D]WI#B-+\0`!3^J9`V)`
MBT9Q`0"1%$;R#@`9W>D`14+J1Q)+\0`!%$-E1A#K!`I/ZHAP0?$`"T_JB7%!
MZI@!5$9`Z@$)S>D.JT'J`PK>Z0`2:P$-]39^TT;*1MWI#(E#ZM1CS>D"JXCJ
M"@@/\M`KV^D`JP&3$>L*`4+K"P**1@:9DT;=Z1(C&NL!`$_JEP-+\0`!@NH(
M`HM&80$`D9!&X@X0ZP@`W>D`B4+J3!)+\0`!3_``"4CJ`@A/\``,$.L("D_J
MAG!!\0`+N0=!ZI8!`"<`)LWI`&=`Z@$&0>H#!]WI`A)/ZDD3`9.TJW%`T$;-
MZ09GS>D2JPY&#_)`*]OI`*O3Z0`2`9L1ZPH!0NL+`D/JV&.*1@&3#)F31MWI
M#B.K"!KK`0!+\0`!<D"+1D_J2!$`D19&3^K88H`9W>D`9T+J21)+\0`!`"<6
M0Q#K!@I/ZH1P0?$`"ZD'0>J4`<WI%JM`Z@$$0>H#!4_J1QM61B%&W>D&-"I&
MS>D,$DM`;Z'1Z0`!2^K::\WX`+`<1M[I`"-/ZDH:#?4X?A(82T'-Z0XCW>D2
M(_L.`IEB0`&3%$8*1MWI#@&`&$'Q``$"&=WI`$5!\0`#3^J)<<WI`B-$Z@H$
M0>J8`=WI`JM/ZHAP3^J9`T#J`0A!Z@,)&NL$"D)&949+1MWI#(G-Z0XC5$;-
MZ0!%B.H""$VDU.D`-$OQ``O=Z19%3^J7"=[I`!*$Z@@$S>D2J\D83^J'>Z!&
M`)Q+ZI8+NJ]+Z@D%`"/@#@:<K$8*&0&<$NL(`D#J1!``G$_J1!I`Z@H`3^J&
M>DKJ"P3=Z0Z:$AC7Z0!GHT:*Z@4*B>H+"<WI!KQ<`0`CR$;11@_RO`O;Z0"K
M1.K2;MWI$KS-^`S@&NL&"HSJ"0R+Z@@+S>D2O'!&#)Q/\``)W?CTPAKK!`94
M`0*4$IPV&=WI`D4$0R!&`)PV&-WI"`$`(8`93^J4"AJ>W>D`1<;I``%*ZH5Z
MW>D05AN93^J$>*T82.H*""I&T?@`X-WI"E8&F6T8#IDN1MWI%$4`)608W>D$
M`0`A$.L(`+!&&I[T1<;I`B/&Z0:)QND(1<;I!`$#T0WU/WV]Z/"/_/<,[0"_
MK_,`@-;!8LH`````+>GX0Q]+>T0`*#G0'DJ;6-/X`)"Y\0`/,-`%>``M&+\]
M+12_`24`)171V?@`0'RQ!T:(1DY&*D8Y1B!&_/?R[1"Y8UT]*P_05O@$3P`L
M\M$@1KWH^(,%1A7X`3\`*QB_/2OYT2T:X.<!-:;K"08L1+80R/@`8"!&O>CX
M@TQ&Y^<$1N7GPF0!`%`!``#PM8.P%4\%1A5+;$9_1/Y8,V@!DR%&*$;_]ZS_
ML+$12P"8^U@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48H1O_WEO\`
M*.C1`9HS:)I"`=$#L/"]_/>0[#!D`0`8`0``4`$``"WI\$\,1M_X7)&%L%9+
M!D;Y1`IX6?@#4#TJ"+\!-"MH($8#D_SW\.P"J0=&,$;_]VW_@$8`*%/0_/?F
M[(="1ME*2P*:6?@#D$_J@@@P>``H&+\]*!2_`2``(`?0,$80^`$_`"L8OSTK
M^=&`&P(WV?@`H#A$_/>D[$KX"```*&O0V?@`('$<`I@S>%+X(``]*QB_`"L#
M<`G00AP1^`$[$$8`*QB_/2L"^`$[]M$"1CTC`W`4^`$[`O@!/P`K^=$`(`.:
M*VB:0DK1!;"]Z/"/"/'_,!3X`3L`^`$_`"OYT>[G(DM9^`.0V?@`L-OX`#"#
MLUM&`.!01E/X!"\`\0$*`"KXT0,P@``:2GI$$VB+L0%&6$;\]Q3LR?@``.BQ
M3^J*"`-&"O$!`@`A0_@B$,WX"*",YP$C$V#\]T3L`9!@L4_JB@A91D)&_/>V
MZP&;R?@`,.?GFD8((-;G3_#_,+#G_/?:ZP"_Q&,!`!@!``!0`0``@&0!`#1+
M-4I[1"WI\$.?L)Y8,V@=DQ"Q`W@'1C.Y'9HS:)I"5=$?L+WH\(/\]P3L!48`
M*//0W_BH@/A$*$;\]ZCL`"@[T,-\T_$N`P?1`WT`*_/0T_$N`Q2_6T)#?0`K
M[-``\1,$.$;\]Q;L@48@1OSW$NQ(1`(P_/?JZT-&3_#_,@$A`90`EX%&_/<D
M[$E&`JH#(/SWCNP!,$A&!=`&FP/T<$.S]8!/$-#\]XKK2$;\]T[K*$;\]VSL
M`"C#T2A&_/>6[#A&_/=6ZZCG__>:_^WG_/=HZP"_7&(!`!@!``#.$P``.+4%
M1A5+%DI[1)Q8(&C\]X3L*48`]:1R`R#\]W+L"+$`(#B](&C\]WCLT/A8,0/T
M<$.S]8!/"=`@:/SW;NS0^%@Q`_1P0[/U($_IT2A&`B'\]QKLL/J`\$`).+UX
M80$`(`$``"WI\$.M]8!=(4V#L"%+#?6`5GU$`:R`1A]([U@$-HE&0/;_<B%&
M>$0[:#-@_/<\ZP`H(=U&'J-=X[$&1C)&+R$@1OSWZNNXL11+ZU@8:/SW,NPS
M1B)&04;\]_SK#?6`4P0S&F@[:)I"$-$-]8!=`["]Z/"#`"[AT0A+ZU@8:/SW
M&NQ*1D%&_/<*Z^?G_/?FZ@IA`0`8`0``HA(``"`!```0M0A,"$M\1.-8&&C\
M]P+L!DH'2P=)HEA[1'E$O>@00/SW>+MV8`$`(`$``!P!``#8$0``'A(```U+
M#DI[1!"U@K"<6"!H_/?FZ__WV?\@:/SWX.L`(0A+`9$(2GM$"$EZ1`"3>43\
M]X+K`K`0O0"_0&`!`"`!``#,%```$0X``/`1```A2R)*>T3PM:WU`%V=6(>P
M#?4`4@.N%#(=3"MH?$038/SW^.H;2T'R`0(!(7M$C>@1`#!&_/<8ZP`H(=L-
M]8!7,$80-T_T@%(Y1OSWG.H$'A;;8!S\]\;J!D8HL3E&(D;\]TSJ`",S50WU
M`%,P1A0S&F@K:)I"!=$-]0!=![#PO0`F\>?\]UCJ]%\!`!@!``#8$0``O!$`
M`/_WLK\MZ?!/K?6!7=_X=(&#L%U+!$;X1`WU@5);2`0R6/@#,`WQ*`D-1GA$
MJ?$(`063&V@38/_W+_TO(09&($;\][3JF+%22"%&>$3_]Y[]($8-]8%3!#,:
M:`6;&VB:0D#PBH`-]8%=`["]Z/"/($;\]Y#J1TEY1()&*$;\]_KJ!T8`*-_0
M1$O?^!"Q>T0&DT-+^T1[1`>3.W@`*TO0+K$Y1C!&_/>NZ0`H2M`X1OSW<NI"
M'KL8NEPO*@;1`"$9<`$X$_@!+2\J^=`*\0$#&$2P]8!?M]JI\00%,DH!(5M&
M>D0`EP&2*$9/](!2`I3\]W#J+4M8^`-P.&C\]_[J*48`]:1R`R#\]]3J2+DX
M:/SW].K0^%@Q`_1P0[/U`$\<T"))`"!Y1/SWINH'1@`OBM`[>``KL]%NL0:9
M,$;\]V+IX+D;20`@>43\]Y3J!T8`+^[1>.<'GP$@M^<!(2A&_/>$Z@`HW-$3
M2"E&>$3_]P[]*$;\]SSJ;.?\]Y+I!I\!(*/G`+]*7P$`&`$``#H1```F$0``
M"A$``-00``#R$```S!```*P0```@`0``7!```#H0```&$````W@[L4(<+RL(
MOQ!&$O@!.P`K^-%P1P"_.+6@LP5X!$:-L_SWW.D!."(8E$(,TB-<+RLQT5,>
M`N`1>"\I+-&<0AI&`_'_,_?1E$(:T`$Z`^`1>"\I!-$:1I1"`O'_,_?3$AN3
M'+/U@%\4V!5((48!,D_T@%-X1`0=($;\]S#I($8XO2\M%=$"(/SWA.D0L2XB
M`H`XO0`@.+U3'@+@$7@O*=30G$(:1@/Q_S/WTY1"S='GYP1(O>@X0'A$_/>Y
MN0"_Z%X!`!P/```MZ?!!C+!*3`*M2D]\1$I.##1_1-_X)($/S/A$OUD!K@_%
M#\S7^`#@#\4D:$1(S?@LX'A$+(#_]S7\0DAX1/_W,?Q!2'A$__<M_$!(>$3_
M]RG\/TAX1/_W)?P^2'A$__<A_#U(>$3_]QW\/$AX1/_W&?Q`1O_W%OPY2'A$
M__<2_#A(>$3_]P[\-TAX1/_W"OPV2'A$__<&_#5(,49X1/_WN_L8L0%&0$;_
M]S#\,4@Q1GA$__>Q^R"Q`48O2'A$__<E_"Y(,49X1/_WION(L0%&*TAX1/_W
M&OPJ22M(>41X1/_W%/P+FCMHFD(>T0RPO>CP@29(,49X1/_WCOLHL0%&(TAX
M1/_W`OSFYR))"B(-\1D`>43\]Y+I`"C=T1Y(#?$C`7A$__?R^];G_/=ZZ`"_
M2`X``,Y<`0`8`0``1@\``-X.``#@#@``X`X``.0.``#D#@``[`X``(`.``#H
M#@``\@X``&X.``#N#@``\@X``/0.``#T#@``_`X``/X.```2#@``&`\``%H.
M``#>#@``4@X``-8.```R#@``$DD32GE$$TL0M7M$C%B"L!AH(V@!DT,<!=`!
MFB-HFD(2T0*P$+T,2&E&>$3_]R;[,+$`>#`H&+\`*!2_`2``(`9+>T088.CG
M_/<<Z$!;`0`8`0``EEP!`(X-``!>7`$`"+7[]]KO^_?,[P"Q`&@(O2WI\$\&
M1B],D;#?^+S@"*U\1-_XN,`$-/Y$+T8/S%[X#(`/QY3H!P#8^``P")R'Z`<`
M#Y/\L=_XF*`'K]_XE)#Z1/E$!N`Q1OOWD._8L57X!$^$L3E&($;_]]CZ@T80
ML0)X`"KOT2!&,4;_]TG[5?@$3P`L[M$/FMCX`#":0A_1$;"]Z/"/,$;\]S[H
M!9!81OSW.N@%FQA$`C#\]Q+HS?@(L%-&S?@$D$_P_S(`E@$A!9#\]TCH!9D@
M1O_W(?O&Y_OWJ.\@7`$`O%H!`!@!``"X#```L@P``"WI\$^M]0%-W_AH1Y.P
M4JO?^&2'?$0+DP3Q(`(>1M_X7#?X1`R0IO'X!P?*!/$L#ECX`S"F\>`+1#2F
M\>P)VD;\/AU&#9.'Z`<`ON@/`-7X`,"JZ`\`#?4!0Y[H`P!$,\/X`,"*Z`,`
ME.@'`(GH!P`Q1M_X#`=X1/_W7/H@L0-X!$8`*T#PBX'_]T;_!48`*%S0*$;[
M]\SO0``!,/OWI.\K>(%&@['?^-RF3$;Z1`"3($931D_P_S(!(0(T^_?6[Q7X
M`3\`*_+1"YM3^.`,&+D5X%OX!`^0L3%&__<K^@1&`"CVT`-X`"OST/_WQ_L`
M*._0($;[]\CO!48`*#71`"17^"10A;,K>'.S*$8$\0$*!^N$!/_WLOM8N53X
M!%\=LRMX"[,H1@KQ`0K_]Z?[`"CST"A&5$;[]ZCO`"C@T`5&$^#[]Z+O`"A`
M\#F!6?@$"P`H`/`K@3%&__?L^0`H]=`#>``K\M#LYP`E*$;?^!AV^_=>[W]$
M!$9(1OOW6N\$1`3R!$0@1OOW,._?^``V3_#_,@$A>T0!D]_X]#7-^`R0>T0`
ME0*7@T;[]V#O6$9/].!Q^_=X[P$P+M#?^-@U6/@#<#AH^_?F[UE&`/6D<@,@
M^_?4[P5&`"@UT-_XO`4!(0R;`"3?^+0E6/@``!MH>D3-^`"P`&C[]W3O#?4!
M0R!&1#,::`V;&VB:0D#PG((-]0%-$["]Z/"/^_<B[P)H$2K+T-_X=`4!(0R;
M`"18^```&V@!DM_X:"7-^`"P>D0`:/OW3N_9YSAH^_>D[]#X6#$#]'!#L_6`
M3[_1.&C[]YKOT/A@D?OW-.Z!1;;1.&C[]Y+OT/A8,</S"`.S]>!_K-$@1OOW
MLNXQ1@1&W_@8!7A$__=0^0`H`/"4@`R;'FC[]_3N`48P1O_W^_L&1@`H`/"(
M@#!&^_>\[@,H!T80W=_XZ!0$.#!$>43[]^KM0+D$+P#PX($W1!?X!3PO*P#P
MVH'_]^K],+D!1C!&^_=X[@Z0`"AIT=_XM!3?^+0$>43?^+1T>$3?^+"4__>.
M^7]$^_>$[M_XJ#3?^*@43_#_,GM$`9/?^*`T>43?^)R$ND8#D7M$S?@`L`$A
M^43X1%]&`I`@1OOWE.X4X/OWBNX#:!$K%]'[]V+N`37-^!"`,D8#E4M&S?@$
MH`$A`)<"D"!&^_=^[D_TX'$@1OOWE.Y#'`9&XM"[1EA&^_>P[=_X0`0A1GA$
M__=)^2!&__?&_2WG__?#_2!&^_=P[@1&)N<-(-_X(%3[]QKN4R-]1(%&<^8%
M1F?F#)L>:'3G"Y]O\!$"`B4`E3L?#),>1D_P_S/[]^SM,48&(@Z8^_=N[1?X
M!#P;N7-X0RL`\'*!`"4`(@`C`)4.F/OWVNT+GM"AT>D``:;QR`K0H]/I`"/*
M^'A0RND"`:;QD`$/D<VAT>D``<KI!"/,H]/I`"/*Z08!S*'1Z0`!RND((P`B
M`",0E,KI"B/*Z0PC1NDR`<WX1+!/]`!"#)D.F/OW,.T$'GK=YQ?:Z0HC)D;Y
M`$'J5'$'D>$`!I'=Z0:)3_``"1CK`@B910B_D$7:Z0PC`M(!,D/Q``-Q#]KX
M>`!!ZL<!")%Y#PF1W>D(5LKI"HFM&%Y!*D8S1LKI#",`*$K0P/%`"`^;H$4,
MF1A$J+^@1D)&^_<4[=KX>#!#1,KX>#!`*[C1#)M01J3K"`281/OWV_\_+";=
M0#P+G23P/PL(\4`,"_&`"<%$K/%`!J7QD`XP:!`V5O@,''=&5O@(+`[Q$`Y6
M^`0\9D4/Q_'14$;[][O_!O%`#,Q%YM$+\4`+!/`_!-A$049((R)&#YC[]R#M
MROAX0'_GW?@P@,KG"YL.F*/QD`<0G-WX1+#[]P#NVO@H4(`AVO@P8,7SQ0)3
M'#@KN50`\YJ`^!C#\3@"`"'[]X[M4$8J#C,.BOAT((KX<V"*^'=0BOAP,#,,
M-@J*^'$PBOAR8"L,+0J*^'4PBOAV4/OW<O\+F-KX"&"@\40"VO@04%#XR.R@
M\3`'H/$("-_X\)'5<D_J'D%/ZAYC47#Y1-KX(!``^$0\VO@8`(+X`^!/ZAXN
MT72"^`+@3^H6;M!S@O@$X$_J%DZ"^`7@UG$V"I9Q+@X6<BX,+0I6<I5R%D8%
M#A5S!0P`"E5S/4:0<P@.$'0(#`D*4'21=`'@%O@!/P"3*$9+1D_P_S(!(0(U
M^_<$[:A%\M%;2$_P_S):2P$A>$0"EP.0>T3-^`"P($8!DP`CA_@H,%5+>T3[
M]^[L=^8,FU]H`"\_]"&N.$;[]\;L`RA_]ANN3DD$.#A$>43[]_;K`"@(OSY&
M$.;#\4`"^!@`(?OW].Q01OOW[OXX1C@B`"'[]^SL7.<,FYMX02M_](FN#)O;
M>$,K?_2$K@R;&WE(*W_T?ZX,FUMY12M_]'JN`)5/\/\S#IUO\#D"*$;[]U+L
M#)XH1BDB,DTQ1OOWT.LQ2WU$3_#_,GM$`9,O2P$A`I8@1LWX`+![1`.5^_>4
M[![F^_?ZZP"_B:O-[P````#^W+J8`````'94,A``````\.'2PP`````!(T5G
M`````$1;`0#:60$`&`$``(H+``!P#```O`L``)0*``"$"P``(`$``"@!``#*
M"P``_`H``&X,``"N"@``%`H``&X)```<"0``;`H```H)``"""P``9`H``&X+
M``!P"```7`D``"H'```T"```K@4``/@&``#,!@``@@<``/P$``!(!@``F4J:
M22WI\$]Z1(>PF$L$K0*54%@!:`.0!9'66#!H^_?`[`1&,&C[][SL*4:0^&0P
MD$B$^&4P>$3^]X+^&+$#>#$K`/#>@/_W;_HP:/OWJ.R)20LC`2)Y1/OWV.L`
M*$O0ADL":7M$4_CT/-+X&(`!*T+=W_@,HD_T@&G?^`BRP/(@"?I$`"7[1`$D
M(^`!:%KX\`R+:%#X)'`)Z@,#L_6`;PB_"6D*T#!H`9+[]WKL`9H"(Q%H`"+[
M]WKK`48X1OOW]NH`*$#PE(!;^/0\`30!-:-"#MTP:/OW9.PJ1@`C04;[]R+L
M`D8`*-#19TM[1%/X]#Q:'JI":M`P:/OW4NQC20,C`2)Y1/OW@NL$1G"Q,&C[
M]T;L(VE>2AEH>D3[]S3K(VD;:)MH6P(`\8F`,&C[]SCL6$D#(P$B>43[]VCK
M!$9XL55(`IEX1/[W^OT%1C!H`"UHT/OW).PC:2I&&6C[]Q3K,&C[]QSL3$U]
M1`1&,&C[]Q;L2DD!(GE$^_=RZTE*>D0!1B!&^_<`ZS!H^_<([``B`ID#1D1(
M@_AE('A$_O?/_01&1?CL#("S3_3@<2!&^_=^ZT,<$2@8OP$K2=@#FP6:&VB:
M0D+1!["]Z/"/`2N2W39-`21]1#!H`33[]^#K04;[]X[J5?CT/*-"]-R#YR]+
M>T13^/0\6AZJ0G_T?*_EYT-X`"L_]""O'.=5^/`,__?\^@1&1?CL#``HQ=$E
M2'A$^_<PZ_OWO.LC2R)I>T13^/`\$&@9:/[W6/^1YS!H^_>NZR-I&6C[]T3K
M;N?[]WSJ&DD#1AI((D9Y1'A$4?CP'`EH^_<.ZP!2`0`8`0``(`$``"H$``#"
M!0``4&0!`#)D`0`N9`$`R&,!`!P%```*!0``]`0``-("``!*8P$`N`0``,@$
M``!P`@``WF(!`,)B`0`P!```AF(!`%IB`0`8!```.+4%1O_WUO@#>,.Q0AP$
M1B\K"+\41A+X`3L`*_C1__?O^0`M&+\`*`C0*W@SL0=)($9Y1/OWTNF$0@+0
M.+T$1NWG*$:]Z#A`_O=,OD8"```%2Q"T>T0%3!M9`[$;:%WX!$O[]Q6Z`+_P
M3@$`,`$``"WI^$,'1@M.B$8+39%&?D3[]YSI?41V&[80"=``)`$T5?@$.TI&
M048X1IA'ID+VT;WH^(.630$`C$T!`'!'`+\(0"WI"("]Z`$``@!P97)L>'-I
M+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(``````E<R\E
M<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X`
M``!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P``
M`%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'
M````4$%27T-!0TA%````4$%27T%21T,`````4$%27T%21U9?,```4$%27T=,
M3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(`
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!
M3CT``#$```!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*``!P87)L`````"YP87(`````)7,E<V-A8VAE+25S)7,`
M`"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````"5S.B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@
M:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``$%21U8`````&````'!E
M<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#,V````56YA
M8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@`````M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)
M4@!435``+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)9
M7U!!5$@`````1%E,1%],24)205)97U!!5$@```!32$Q)0E]0051(``!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I
M;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP
M+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!]
M(&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)0
M05)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]
M("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2![
M"F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]
M("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^
M("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@
M9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@
M7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P
M<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@
M/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X]
M(#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R
M-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F
M9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").
M(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E
M9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP
M9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L
M;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H
M("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D
M9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M
M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B
M8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U
M<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F
M:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE
M(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)
M3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE
M.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O
M<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P
M-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN
M960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R
M-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY
M("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*
M8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N
M;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O
M(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF
M("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\
M7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*
M?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@
M/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A
M;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D
M:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(]
M)'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E
M="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L
M92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY
M($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z
M.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@
M/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E
M86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I
M9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA
M;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO
M72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D
M,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE
M(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N
M=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U
M9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A
M;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@
M/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D[
M"B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E
M<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA
M;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O
M=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X]
M(")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D[
M"B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?
M+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M
M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*
M<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E
M('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO
M;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H
M)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N
M,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X
M*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G
M;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*
M?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA
M<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G
M/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@
M)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@
M)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4[
M"G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP
M;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M
M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD
M<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE
M(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS
M=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE
M=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*
M?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!
M4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,
M14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L
M96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L
M=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!,=_]_`0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````M&0``[1@`
M```````!`````0````$```#?`0```0```.H!```!````]`$```$```!#`@``
M`0```)X#```!````Q`,```P````@$P``#0```!1@```9````>*T!`!L````$
M````&@```'RM`0`<````!````/7^_V^T`0``!0```)`)```&````H`(```H`
M```H!0``"P```!`````5``````````,```"LK@$``@`````"```4````$0``
M`!<````@$0``$0```/@/```2````*`$``!,````(````&`````````#[__]O
M`0``"/[__V^8#P``____;P,```#P__]ON`X``/K__V\7````````````````
M`````````````````````````````````````````(2M`0```````````"P3
M```L$P``+!,``"P3```L$P``+!,``"P3```L$P``+!,``"P3```L$P``+!,`
M`"P3```L$P``+!,``"P3```L$P``+!,``"P3```L$P``+!,``"P3```L$P``
M+!,``"P3```L$P``+!,``"P3```L$P``+!,``"P3```L$P``+!,``"P3```L
M$P``+!,``"P3```L$P``+!,``"P3```L$P``+!,``"P3```L$P``+!,``"P3
M```L$P``+!,``"P3```L$P``+!,``"P3```L$P``+!,``"P3```L$P``+!,`
M`"P3```L$P``+!,``"P3```L$P``+!,``"P3```18```````````````````
M```````````````````````````$L`$``````-5?````````418`````````
M````````````````````!+`!`/____^,8P``G&,``*1C``"L8P``M&,``,AC
M````````A&,``*Q@````````A&$``(AA``!X8P``M&```(!C````````9&,`
M`&QC````````U&,``$=#0SH@*$1E8FEA;B`V+C,N,"TR*2`V+C,N,"`R,#$V
M,3(R.0!'0T,Z("A$96)I86X@-BXR+C$M-2D@-BXR+C$@,C`Q-C$Q,C0`03(`
M``!A96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<
M`2(!`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU
M+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S
M:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT
M97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N96A?9G)A;64`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N9V]T`"YD871A`"YB
M<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````
M````````````````````````````````"P````$````"````5`$``%0!```9
M```````````````!`````````!,````'`````@```'`!``!P`0``(```````
M````````!``````````A````!P````(```"0`0``D`$``"0`````````````
M``0`````````-````/;__V\"````M`$``+0!``#L````!0`````````$````
M!````#X````+`````@```*`"``"@`@``\`8```8````#````!````!````!&
M`````P````(```"0"0``D`D``"@%``````````````$`````````3@```/__
M_V\"````N`X``+@.``#>````!0`````````"`````@```%L```#^__]O`@``
M`)@/``"8#P``8`````8````#````!`````````!J````"0````(```#X#P``
M^`\``"@!```%``````````0````(````<P````D```!"````(!$``"`1````
M`@``!0```!8````$````"````'P````!````!@```"`3```@$P``#```````
M````````!`````````!W`````0````8````L$P``+!,``"`#````````````
M``0````$````@@````$````&````4!8``%`6``#$20`````````````(````
M`````(@````!````!@```!1@```48```"```````````````!`````````".
M`````0````(````<8```'&```+1```````````````0`````````E@````$`
M`'""````T*```-"@```(````#0`````````$`````````*$````!`````@``
M`-B@``#8H```!```````````````!`````````"K````#@````,```!XK0$`
M>*T```0```````````````0````$````MP````\````#````?*T!`'RM```$
M```````````````$````!````,,````!`````P```("M`0"`K0``!```````
M````````!`````````#(````!@````,```"$K0$`A*T``"@!```&````````
M``0````(````T0````$````#````K*X!`*RN``!4`0`````````````$````
M!````-8````!`````P````"P`0``L```7```````````````!`````````#<
M````"`````,```!<L`$`7+```!@0``````````````0`````````X0````$`
M```P`````````%RP``!*```````````````!`````0```.H````#``!P````
M``````"FL```,P```````````````0`````````!`````P``````````````
8V;```/H```````````````$`````````
